SystemOrganization addCategory: #GODSocialNetIOTests!

TestCase subclass: #SNETFacebookFetcherTest
	instanceVariableNames: 'fetcher'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODSocialNetIOTests'!

!SNETFacebookFetcherTest methodsFor: 'initialize-release' stamp: 'T.A. 10/31/2014 16:49'!
setUp
	fetcher := SNETFacebookFetcher new.
	fetcher connect.! !

!SNETFacebookFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:58'!
testConnect
	"Tests Facebook fetcher connection with the API."
	|result| 

	fetcher connect.
	
	result := fetcher  instVarNamed: 'accessToken'.

	self assert: (result includesSubString: 'access_token').
	
	self assert: (result isEmpty not).! !

!SNETFacebookFetcherTest methodsFor: 'tests' stamp: 'TA 11/3/2014 23:46'!
testEvents
	"Tests the search for events."
	|result item|

	result := fetcher events: 'party'.

	self assert: (result notNil).

	self assert: (result size) > 0.

	item := result getEvent: 1.

	self assert: (item isMemberOf: SNETFacebookEvent).

	self assert: (item getName isEmpty not).

	! !

!SNETFacebookFetcherTest methodsFor: 'tests' stamp: 'TA 11/3/2014 23:45'!
testEventsSince
	"Tests the search for events with filters."
	|result item|

	result := fetcher events: 'party' since: '2014-01-01' asDate.

	self assert: (result notNil).

	self assert: (result size) > 0.

	item := result getEvent: 1.

	self assert: (item isMemberOf: SNETFacebookEvent).

	self assert: (item getName isEmpty not).! !

!SNETFacebookFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:58'!
testEventsSinceUntil
	"Tests the search for events with filters."
	|result item|

	result := fetcher events: 'party' since: '2014-01-01' asDate until: '2015-01-01' asDate.

	self assert: (result notNil).

	self assert: (result size) > 0.

	item := result getEvent: 1.

	self assert: (item isMemberOf: SNETFacebookEvent).

	self assert: (item getName isEmpty not).

	self assert: (item getLocation isEmpty not).! !

!SNETFacebookFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:57'!
testGetById
	"Tests an APP search by id."
	|result|

	result := fetcher getById: '743980072335668'.

	self assert: (result size) > 0.! !

!SNETFacebookFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:57'!
testGroupDescription
	"Tests group description search."
	|result|

	result := fetcher groupDescription: '161572000688140'.

	self assert: (result notNil).

	self assert: (result isMemberOf: SNETFacebookGroupDescriptionData).
	
	self assert: (result getDescription isEmpty not).! !

!SNETFacebookFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:57'!
testGroups
	"Tests group search."
	|result item|

	result := fetcher groups: 'party'.

	self assert: (result size) > 0.

	item := result getGroup: 1.

	self assert: (item isMemberOf: SNETFacebookGroup).

	self assert: (item getName isEmpty not).

	! !

!SNETFacebookFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:57'!
testPageDescription
	"Tests page description search."
	|result|

	result := fetcher pageDescription: '152871911535347'.

	self assert: (result notNil).

	self assert: (result isMemberOf: SNETFacebookPageDescriptionData).
	
	self assert: (result getDescription isEmpty not).! !

!SNETFacebookFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:57'!
testPages
	"Tests page search."
	|result item|

	result := fetcher pages: 'Santo Closet'.

	self assert: (result size) > 0.

	item := result getPage: 1.

	self assert: (item isMemberOf: SNETFacebookPage).

	self assert: (item getName isEmpty not).! !

!SNETFacebookFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:57'!
testPosts
	"Tests a simple Facebook user posts search."
	|result item|

	result := fetcher posts: 'nike'.

	self assert: (result size) > 0.

	item := result getPost: 1.

	self assert: (item isMemberOf: SNETFacebookPost).

	self assert: (item getMessage isEmpty not).! !

!SNETFacebookFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:57'!
testPostsSince
	"Tests a simple Facebook user posts search filtered by date."
	|result item|

	result := fetcher posts: 'nike' since: '2014-01-01' asDate.

	self assert: (result size) > 0.

	item := result getPost: 1.

	self assert: (item isMemberOf: SNETFacebookPost).

	self assert: (item getMessage isEmpty not).! !

!SNETFacebookFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:57'!
testPostsSinceUntil
	"Tests a simple Facebook user posts search filtered by date."
	|result item|

	result := fetcher posts: 'nike' since: '2014-01-01' asDate until: '2014-10-01' asDate.

	self assert: (result size) > 0.

	item := result getPost: 1.

	self assert: (item isMemberOf: SNETFacebookPost).

	self assert: (item getMessage isEmpty not).! !

!SNETFacebookFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:56'!
testUsers
	"Tests a simple Facebook user search. The user search seems to be broken on Graph API v2.1."
	|result|

	result := fetcher users: 'Eduardo Barreto Alexandre'.

	self assert: (result notNil).

	"User search is bugged on facebook!!"

	"item := result getPost: 1.

	self assert: (item isMemberOf: SNETFacebookUsersData).

	self assert: (item getMessage size) > 0."! !

TestCase subclass: #SNETTwitterFetcherTest
	instanceVariableNames: 'fetcher'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODSocialNetIOTests'!

!SNETTwitterFetcherTest methodsFor: 'initialize-release' stamp: 'T.A. 10/31/2014 16:48'!
setUp
	fetcher := SNETTwitterFetcher new.
	fetcher connect.! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:56'!
testConnect
	"Tests Twitter fetcher connection with the API."
	|result| 

	fetcher connect.
	
	result := fetcher  instVarNamed: 'accessToken'.
	
	self assert: (result isEmpty not).! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:56'!
testPosts
	"Tests a simple Twitter user posts search."
	|result item|

	result := fetcher posts: '@usponline'.

	self assert: (result size) > 0.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).
	
	"self assert: (item getRetweets) > 0."
	
	"self assert: (item getFavorited) > 0."
	! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:56'!
testPostsMaximum
	"Tests a simple Twitter user posts search with a maximum number of results."
	|result item|

	result := fetcher posts: '@usponline' maximum: 20.

	self assert: (result size) = 20.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).
	
	"self assert: (item getRetweets) > 0."
	
	"self assert: (item getFavorited) > 0."! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:56'!
testTweets
	"Tests search tweets by message text."
	|result item|

	result := fetcher tweets: 'usp convida'.

	self assert: (result size) > 0.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:56'!
testTweetsByHashtag
	"Tests tweets search by hashtag."
	|result item|

	result := fetcher tweets: '#teste'.

	self assert: (result size) > 0.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).
	
	"self assert: (item getRetweets) > 0."
	
	"self assert: (item getFavorited) = 0."! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:55'!
testTweetsFromUser
	"Tests tweet search by user."
	|result item|

	result := fetcher tweetsFrom: '#SpaceShipTwo' user: '@nasa'.

	self assert: (result size) > 0.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:55'!
testTweetsFromUserMaximum
	"Tests search tweets from user with a limited number of results."
	|result item|

	result := fetcher tweetsFrom: '#SpaceShipTwo' user: '@nasa' maximum: 20.

	self assert: (result size) = 20.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:55'!
testTweetsFromUserSince
	"Tests search tweets from user by date."
	|result item|

	result := fetcher tweetsFrom: '#SpaceShipTwo' user: '@nasa' since: '2014-01-01' asDate.

	self assert: (result size) > 0.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:55'!
testTweetsFromUserSinceMaximum
	"Tests search tweets from user by date."
	|result item|

	result := fetcher tweetsFrom: '#SpaceShipTwo' user: '@nasa' since: '2014-01-01' asDate maximum: 20.

	self assert: (result size) = 20.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:55'!
testTweetsFromUserSinceUntil
	"Tests search tweets from user by date range."
	|result item|

	result := fetcher tweetsFrom: '#SpaceShipTwo' user: '@nasa' since: '2014-01-01' asDate until: '2014-12-01' asDate.

	self assert: (result size) > 0.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:55'!
testTweetsFromUserSinceUntilMaximum
	"Tests search tweets from user by date range with a maximum number of results."
	|result item|

	result := fetcher tweetsFrom: '#SpaceShipTwo' user: '@nasa' since: '2014-01-01' asDate until: '2014-12-01' asDate maximum: 20.

	self assert: (result size) = 20.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:55'!
testTweetsFromUserUntil
	"Tests search tweets from user until a certain date."
	|result item|

	result := fetcher tweetsFrom: '#nasa' user: '@NASA' until: '2014-10-30' asDate.

	self assert: (result size) > 0.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:55'!
testTweetsFromUserUntilMaximum
	"Tests search tweets from user until a certain date with a maximum number of results."
	|result item|

	result := fetcher tweetsFrom: '#nasa' user: '@NASA' until: '2014-10-30' asDate maximum:20.

	self assert: (result size) = 20.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:54'!
testTweetsJsonTruncatedBug
	"Debug test: when the json response is too large, it gets truncated and cannot be converted.."
	|result item|

 	"This should work" 
	self shouldnt: [fetcher tweets: 'dilmabr'] raise: Error description: 'Response is being truncated.'.
! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:54'!
testTweetsMaximum
	"Tests search by text with a maximum number of results."
	|result item|

	result := fetcher tweets: '#teste' maximum: 20.

	self assert: (result size) = 20.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).
	! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:54'!
testTweetsSinceMaximum
	"Tests search by text tweeted since a specific date with a maximum number of results."
	|result item|

	result := fetcher tweets: '#teste' since: '2014-10-30' asDate  maximum: 20.

	self assert: (result size) = 20.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).
	
	"self assert: (item getRetweets) > 0."
	
	"self assert: (item getFavorited) = 0."! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:54'!
testTweetsSinceUntilMaximum
	"Tests search by text until a certain date, with a max number of results."
	|result item|

	result := fetcher tweets: 'geraldo alckmin foi' since: '2014-10-01' asDate until: '2014-12-01' asDate maximum: 20.

	self assert: (result size) = 20.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).
	
	! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:53'!
testTweetsUntil
	"Tests search by text or hashtag until a certain date."
	|result item|

	result := fetcher tweets: '#teste' until: '2014-10-01' asDate.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).! !

!SNETTwitterFetcherTest methodsFor: 'tests' stamp: 'EBA 11/3/2014 20:53'!
testTweetsUntilMaximum
	"Tests search by text."
	|result item|

	result := fetcher tweets: '#teste' until: '2014-01-01' asDate maximum: 20.

	self assert: (result size) = 20.

	item := result getTweet: 1.

	self assert: (item isMemberOf: SNETTwitterTweet).

	self assert: (item getMessage isEmpty not).! !
